@@ -1,6 +1,9 @@
+"""Helper for assigning and accessing pandas columns"""
+
 # flake8: noqa
-from ._version import __version__
 from .core import ChildColAssigner, ColAccessor, ColAssigner
 from .meta_base import get_all_cols, get_att_value
 from .type_hinting import Col
 from .util import camel_to_snake
+
+__version__ = "0.3.1"
